@@ -24,10 +24,10 @@ const sourceURL = getGitHubURL(repository.url, commitID || version)
 const fullversion = commitID ? `${version}-${commitID}` : version
 
 const packageConfig = {
-  version: version,
+  version,
   minimumCompatibleVersion: '0.5.0',
-  fullversion: fullversion,
-  sourceURL: sourceURL
+  fullversion,
+  sourceURL
 }
 
 const configFilePath = path.resolve(appRootPath, process.env.CMD_CONFIG_FILE ||
